##  5. Additional information about Data collection and processing
### Legal action
The User's Personal Data may be used for legal purposes by the Data Controller in court or in the stages leading to possible legal action arising from improper use of this Application or the related Services.
The User declares to be aware that the Data Controller may be required to reveal personal data upon request of public authorities.
### Additional Information
More details concerning the collection or processing of Personal Data may be requested at any time. Please see the contact information at the beginning of this document.
### Changes to this privacy policy
The Data Controller reserves the right to make changes to this privacy policy at any time by giving notice to its Users on this page and possibly within this Application and/or - as far as technically and legally feasible - sending a notice to Users via any contact information available to the Data Controller. It is strongly recommended to check this page often, referring to the date of the last modification listed at the bottom.
YesNo
Send
